@@ -300,6 +300,24 @@ class VKIE(VKBaseIE):
                 'upload_date': '20250130',
             },
         },
+        {
+            'url': 'https://vkvideo.ru/video-50883936_456244102',
+            'info_dict': {
+                'id': '-50883936_456244102',
+                'ext': 'mp4',
+                'title': 'Добивание Украины // Техник в коме // МОЯ ЗЛОСТЬ №140',
+                'description': 'md5:a9bc46181e9ebd0fdd82cef6c0191140',
+                'uploader': 'Стас Ай, Как Просто!',
+                'uploader_id': '-50883936',
+                'comment_count': int,
+                'like_count': int,
+                'duration': 4651,
+                'thumbnail': r're:https?://.+\.jpg',
+                'chapters': 'count:59',
+                'timestamp': 1743333869,
+                'upload_date': '20250330',
+            },
+        },
         {
             # live stream, hls and rtmp links, most likely already finished live
             # stream by the time you are reading this comment
@@ -530,21 +548,21 @@ class VKIE(VKBaseIE):
             'formats': formats,
             'subtitles': subtitles,
             **traverse_obj(mv_data, {
-                'title': ('title', {unescapeHTML}),
+                'title': ('title', {str}, {unescapeHTML}),
                 'description': ('desc', {clean_html}, filter),
                 'duration': ('duration', {int_or_none}),
                 'like_count': ('likes', {int_or_none}),
                 'comment_count': ('commcount', {int_or_none}),
             }),
             **traverse_obj(data, {
-                'title': ('md_title', {unescapeHTML}),
+                'title': ('md_title', {str}, {unescapeHTML}),
                 'description': ('description', {clean_html}, filter),
                 'thumbnail': ('jpg', {url_or_none}),
-                'uploader': ('md_author', {str}),
+                'uploader': ('md_author', {str}, {unescapeHTML}),
                 'uploader_id': (('author_id', 'authorId'), {str_or_none}, any),
                 'duration': ('duration', {int_or_none}),
                 'chapters': ('time_codes', lambda _, v: isinstance(v['time'], int), {
-                    'title': ('text', {str}),
+                    'title': ('text', {str}, {unescapeHTML}),
                     'start_time': 'time',
                 }),
             }),
